# FtoC

A PyPi module allowing the user to convert a temperature from farenheit to celsius!

![Generic badge](https://img.shields.io/badge/version-0.0.3-green.svg)

## How does it work?

**Use import FtoC to get access to the convert functions:**
```python
from FtoC import convert
```
and then convert:
```python
convert(farenheit)
```

## Why FtoC

`convert` from FtoC works efficiently and is a very simple and convenient abstraction of an otherwise difficult task.

### Example
```python
convert(86.0)
>> 30.0
```

## Installation

On bash:
```bash
$ pip install FtoC
```

On windows:
```
python -m pip install FtoC
```

## Usage

* [Contributing](#Contributing)


## Contributing

1. Fork it ( https://github.com/ )
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Make sure that the script does not have errors or warnings
6. Create a new Pull Request

## License

This tool is open source under the [MIT License](https://opensource.org/licenses/MIT) terms.

[[Back To Top]](#FtoC)